@@ -73,26 +73,41 @@ setMethod("names", "GAlignmentPairs",
     function(x) x@NAMES
 )
 
+.make_it_real <- function(strand, strand_mode)
+{
+    if (strand_mode == 0L) 
+        return(Rle(strand("*"), length(strand)))
+    invertStrand(strand)
+}
+
+.first_strand <- function(x, real.strand=FALSE)
+{
+    if (!isTRUEorFALSE(real.strand))
+        stop("'real.strand' must be TRUE or FALSE")
+    ans <- strand(x@first)
+    if (real.strand && strandMode(x) != 1L)
+        ans <- .make_it_real(ans, strandMode(x))
+    ans
+}
+
+.last_strand <- function(x, real.strand=FALSE)
+{
+    if (!isTRUEorFALSE(real.strand))
+        stop("'real.strand' must be TRUE or FALSE")
+    ans <- strand(x@last)
+    if (real.strand && strandMode(x) != 2L)
+        ans <- .make_it_real(ans, strandMode(x))
+    ans
+}
+
 setMethod("first", "GAlignmentPairs",
-    function(x, real.strand=FALSE, invert.strand=FALSE)
+    function(x, real.strand=FALSE)
     {
         if (!isTRUEorFALSE(real.strand))
             stop("'real.strand' must be TRUE or FALSE")
-        if (!identical(invert.strand, FALSE)) {
-            msg <- c("Using the 'invert.strand' argument when calling ",
-                     "first() on a GAlignmentPairs object is defunct.")
-            .Defunct(msg=wmsg(msg))
-        }
         ans <- setNames(x@first, names(x))
-        if (invert.strand)
-            return(invertStrand(ans))
-        if (real.strand) {
-            if (strandMode(x) == 0L) {
-                strand(ans) <- "*"
-            } else if (strandMode(x) == 2L) {
-                ans <- invertStrand(ans)
-            }
-        }
+        if (real.strand && strandMode(x) != 1L)
+            strand(ans) <- .first_strand(x, real.strand=TRUE)
         ans
     }
 )
@@ -102,43 +117,33 @@ setGeneric("last", function(x, ...) standardGeneric("last"))
 setMethod("last", "GAlignmentPairs", function(x, ...) second(x, ...))
 
 setMethod("second", "GAlignmentPairs",
-    function(x, real.strand=FALSE, invert.strand=FALSE)
+    function(x, real.strand=FALSE)
     {
         if (!isTRUEorFALSE(real.strand))
             stop("'real.strand' must be TRUE or FALSE")
-        if (!identical(invert.strand, FALSE)) {
-            msg <- c("Using the 'invert.strand' argument when calling ",
-                     "last() on a GAlignmentPairs object is defunct.")
-            .Defunct(msg=wmsg(msg))
-        }
         ans <- setNames(x@last, names(x))
-        if (invert.strand)
-            return(invertStrand(ans))
-        if (real.strand) {
-            if (strandMode(x) == 0L) {
-                strand(ans) <- "*"
-            } else if (strandMode(x) == 1L) {
-                ans <- invertStrand(ans)
-            }
-        }
+        if (real.strand && strandMode(x) != 2L)
+            strand(ans) <- .last_strand(x, real.strand=TRUE)
         ans
     }
 )
 
-          
 setMethod("seqnames", "GAlignmentPairs",
-    function(x) seqnames(x@first)
+    function(x)
+    {
+        ans <- seqnames(x@first)
+        ans[seqnames(x@last) != ans] <- NA
+        ans
+    }
 )
 
 setMethod("strand", "GAlignmentPairs",
     function(x)
     {
-        if (strandMode(x) == 0L)
-            return(strand(Rle("*", length(x))))
-        if (strandMode(x) == 1L)
-            strand(x@first)
-        else
-            strand(x@last)
+        ans <- .first_strand(x, real.strand=TRUE)
+        x_last_strand <- .last_strand(x, real.strand=TRUE)
+        ans[ans != x_last_strand] <- "*"
+        ans
     }
 )
 
@@ -178,6 +183,16 @@ setReplaceMethod("strandMode", "GAlignmentPairs",
     }
 )
 
+setMethod("invertStrand", "GAlignmentPairs",
+    function(x)
+    {
+        strand_mode <- strandMode(x)
+        if (strand_mode != 0L)
+            strandMode(x) <- 3L - strand_mode
+        x
+    }
+)
+
 setReplaceMethod("names", "GAlignmentPairs",
     function(x, value)
     {
@@ -189,18 +204,6 @@ setReplaceMethod("names", "GAlignmentPairs",
     }
 )
 
-setReplaceMethod("strand", "GAlignmentPairs",
-    function(x, value)
-    {
-        msg <- c("The strand setter for GAlignmentPairs objects ",
-                 "is defunct. You can use strandMode() to control the ",
-                 "behavior of the strand() getter in accordance with the ",
-                 "stranded protocol that was used to generate the ",
-                 "paired-end data (see '?strandMode').")
-        .Defunct(msg=wmsg(msg))
-    }
-)
-
 setMethod("seqlevelsInUse", "GAlignmentPairs",
     function(x)
     {
@@ -402,6 +405,166 @@ setMethod("unlist", "GAlignmentPairs",
 ### Coercion.
 ###
 
+### 'caller' must be "ranges" or "granges".
+.error_on_discordant_seqnames <- function(caller)
+{
+    if (caller == "ranges") {
+        range_type <- "range"
+        returned_object <- "IRanges"
+        a_returned_object <- "an IRanges"
+        alternate_caller <- "rglist"
+        alternate_returned_object <- "an IRangesList"
+    } else {
+        range_type <- "genomic range"
+        returned_object <- "GRanges"
+        a_returned_object <- "a GRanges"
+        alternate_caller <- "grglist"
+        alternate_returned_object <- "a GRangesList"
+    }
+    wmsg(
+        "For some pairs in 'x', the 2 alignments are not on the same ",
+        "chromosome. Cannot associate a unique ", range_type, " to ",
+        "such pairs. Please call ", caller, "() with ",
+        "'on.discordant.seqnames=\"drop\"' to drop these pairs, ",
+        "or with 'on.discordant.seqnames=\"split\"' to represent ",
+        "each of them with 2 ", range_type, "s in the returned ",
+        returned_object, " object. Note that in both cases the returned ",
+        "object won't be parallel to 'x'. Alternatively, please ",
+        "consider using ", alternate_caller, "() instead of ", caller, "() ",
+        "to turn 'x' into ", alternate_returned_object, " object instead of ",
+        a_returned_object, " object. See ?GAlignmentPairs for more ",
+        "information."
+    )
+}
+
+.make_split_IRanges_from_GAlignmentPairs <- function(x, use.names=TRUE,
+                                                        use.mcols=FALSE)
+{
+    x_first_ranges <- ranges(x@first, use.names=FALSE)
+    x_last_ranges <- ranges(x@last, use.names=FALSE)
+
+    x_len <- length(x)
+    collate_subscript <- S4Vectors:::make_XYZxyz_to_XxYyZz_subscript(x_len)
+    partitioning <- PartitioningByEnd(2L * seq_len(x_len))
+
+    range_pairs <- relist(c(x_first_ranges, x_last_ranges)[collate_subscript],
+                          partitioning)
+
+    x_first_seqnames <- seqnames(x@first)
+    x_last_seqnames <- seqnames(x@last)
+    merge_idx <- x_first_seqnames == x_last_seqnames
+
+    range_pairs[merge_idx] <- range(range_pairs[merge_idx])
+    if (use.names)
+        names(range_pairs) <- names(x)
+
+    ans <- unlist(range_pairs, use.names=use.names)
+    if (use.mcols) {
+        i <- rep.int(seq_len(x_len), elementNROWS(range_pairs))
+        mcols(ans) <- extractROWS(mcols(x), i)
+    }
+    ans
+}
+
+setMethod("ranges", "GAlignmentPairs",
+    function(x, use.names=TRUE, use.mcols=FALSE,
+                on.discordant.seqnames=c("error", "drop", "split"))
+    {
+        if (!isTRUEorFALSE(use.names))
+            stop("'use.names' must be TRUE or FALSE")
+        if (!isTRUEorFALSE(use.mcols))
+            stop("'use.mcols' must be TRUE or FALSE")
+        on.discordant.seqnames <- match.arg(on.discordant.seqnames)
+
+        ans_seqnames <- seqnames(x)
+        is_discordant <- is.na(ans_seqnames)
+        if (any(is_discordant)) {
+            if (on.discordant.seqnames == "error")
+                stop(.error_on_discordant_seqnames("ranges"))
+            if (on.discordant.seqnames == "split")
+                return(.make_split_IRanges_from_GAlignmentPairs(x,
+                           use.names=use.names, use.mcols=use.mcols))
+            ## on.discordant.seqnames == "drop"
+            x <- x[!is_discordant]
+        }
+
+        x_first_ranges <- ranges(x@first, use.names=FALSE)
+        x_last_ranges <- ranges(x@last, use.names=FALSE)
+        ans <- punion(x_first_ranges, x_last_ranges, fill.gap=TRUE)
+        if (use.names)
+            names(ans) <- names(x)
+        if (use.mcols)
+            mcols(ans) <- mcols(x)
+        ans
+    }
+)
+
+.make_split_GRanges_from_GAlignmentPairs <- function(x, use.names=TRUE,
+                                                        use.mcols=FALSE)
+{
+    x_first_seqnames <- seqnames(x@first)
+    x_last_seqnames <- seqnames(x@last)
+    is_discordant <- x_first_seqnames != x_last_seqnames
+    ndiscordant <- sum(is_discordant)
+    collate_subscript <-
+        S4Vectors:::make_XYZxyz_to_XxYyZz_subscript(ndiscordant)
+    partitioning <- PartitioningByEnd(2L * seq_len(ndiscordant))
+
+    seqnames1 <- x_first_seqnames[is_discordant]
+    seqnames2 <- x_last_seqnames[is_discordant]
+    discordant_seqnames <- relist(c(seqnames1, seqnames2)[collate_subscript],
+                                  partitioning)
+
+    ans_seqnames <- as(x_first_seqnames, "List")
+    ans_seqnames[is_discordant] <- discordant_seqnames
+
+    ans_ranges <- .make_split_IRanges_from_GAlignmentPairs(x,
+                      use.names=use.names, use.mcols=use.mcols)
+
+    strand1 <- .first_strand(x, real.strand=TRUE)[is_discordant]
+    strand2 <- .last_strand(x, real.strand=TRUE)[is_discordant]
+    discordant_strand <- relist(c(strand1, strand2)[collate_subscript],
+                                partitioning)
+    ans_strand <- as(strand(x), "List")
+    ans_strand[is_discordant] <- discordant_strand
+
+    GRanges(unlist(ans_seqnames, use.names=FALSE),
+            ans_ranges,
+            unlist(ans_strand, use.names=FALSE),
+            seqinfo=seqinfo(x))
+}
+
+setMethod("granges", "GAlignmentPairs",
+    function(x, use.names=TRUE, use.mcols=FALSE,
+                on.discordant.seqnames=c("error", "drop", "split"))
+    {
+        if (!isTRUEorFALSE(use.mcols))
+            stop("'use.mcols' must be TRUE or FALSE")
+        on.discordant.seqnames <- match.arg(on.discordant.seqnames)
+
+        ans_seqnames <- seqnames(x)
+        is_discordant <- is.na(ans_seqnames)
+        if (any(is_discordant)) {
+            if (on.discordant.seqnames == "error")
+                stop(.error_on_discordant_seqnames("granges"))
+            if (on.discordant.seqnames == "split")
+                return(.make_split_GRanges_from_GAlignmentPairs(x,
+                           use.names=use.names, use.mcols=use.mcols))
+            ## on.discordant.seqnames == "drop"
+            x <- x[!is_discordant]
+            ans_seqnames <- seqnames(x)
+        }
+
+        ans <- GRanges(ans_seqnames,
+                       ranges(x, use.names=use.names),
+                       strand(x),
+                       seqinfo=seqinfo(x))
+        if (use.mcols)
+            mcols(ans) <- mcols(x)
+        ans
+    }
+)
+
 ### Shrink CompressedList 'x' (typically a GRangesList) by half by combining
 ### pairs of consecutive top-level elements.
 shrinkByHalf <- function(x)
@@ -425,18 +588,12 @@ shrinkByHalf <- function(x)
 ### FIXME: Behavior is currently undefined (and undocumented) when
 ### strandMode(x) is 0. Fix this!
 setMethod("grglist", "GAlignmentPairs",
-    function(x, use.mcols=FALSE, order.as.in.query=FALSE, drop.D.ranges=FALSE)
+    function(x, use.names=TRUE, use.mcols=FALSE, drop.D.ranges=FALSE)
     {
+        if (!isTRUEorFALSE(use.names))
+            stop("'use.names' must be TRUE or FALSE")
         if (!isTRUEorFALSE(use.mcols))
             stop("'use.mcols' must be TRUE or FALSE")
-        if (!identical(order.as.in.query, FALSE)) {
-            msg <- c("Starting with BioC 3.2, the \"grglist\" method for ",
-                     "GAlignmentPairs objects *always* returns the ranges ",
-                     "\"ordered as in query\". Therefore the ",
-                     "'order.as.in.query' argument is now ignored (and ",
-                     "defunct).")
-            .Defunct(msg=wmsg(msg))
-        }
         x_mcols <- mcols(x)
         if (use.mcols && "query.break" %in% colnames(x_mcols))
             stop("'mcols(x)' cannot have reserved column \"query.break\"")
@@ -457,7 +614,8 @@ setMethod("grglist", "GAlignmentPairs",
                        order.as.in.query=TRUE,
                        drop.D.ranges=drop.D.ranges)
         ans <- shrinkByHalf(grl)
-        names(ans) <- names(x)
+        if (use.names)
+            names(ans) <- names(x)
         ans_mcols <- DataFrame(query.break=mcols(ans)$nelt1)
         if (use.mcols)
             ans_mcols <- cbind(ans_mcols, x_mcols)
@@ -466,28 +624,14 @@ setMethod("grglist", "GAlignmentPairs",
     }
 )
 
-setMethod("granges", "GAlignmentPairs",
-    function(x, use.mcols=FALSE)
-    {
-        if (!isTRUEorFALSE(use.mcols))
-            stop("'use.mcols' must be TRUE or FALSE")
-        rg <- range(grglist(x))
-        if (!all(elementNROWS(rg) == 1L))
-            stop("For some pairs in 'x', the first and last alignments ",
-                 "are not aligned to the same chromosome and strand. ",
-                 "Cannot extract a single range for them.")
-        ans <- unlist(rg)
-        if (use.mcols)
-            mcols(ans) <- mcols(x)
-        ans
-    }
-)
-
-setAs("GAlignmentPairs", "GRangesList",
-    function(from) grglist(from, use.mcols=TRUE)
+setAs("GAlignmentPairs", "Ranges",
+    function(from) ranges(from, use.names=TRUE, use.mcols=TRUE)
 )
 setAs("GAlignmentPairs", "GRanges",
-    function(from) granges(from, use.mcols=TRUE)
+    function(from) granges(from, use.names=TRUE, use.mcols=TRUE)
+)
+setAs("GAlignmentPairs", "GRangesList",
+    function(from) grglist(from, use.names=TRUE, use.mcols=TRUE)
 )
 setAs("GAlignmentPairs", "GAlignments",
     function(from) unlist(from, use.names=TRUE)
@@ -732,29 +876,3 @@ setMethod("c", "GAlignmentPairs",
     }
 )
 
-
-### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-### Old stuff (deprecated & defunct)
-###
-
-setGeneric("left", function(x, ...) standardGeneric("left"))
-setGeneric("right", function(x, ...) standardGeneric("right"))
-
-setMethod("left", "GAlignmentPairs",
-    function(x, ...)
-    {
-        msg <- c("The left() and right() getters are defunct ",
-                 "for GAlignmentPairs objects.")
-        .Defunct(msg=wmsg(msg))
-    }
-)
-
-setMethod("right", "GAlignmentPairs",
-    function(x, ...)
-    {
-        msg <- c("The left() and right() getters are defunct ",
-                 "for GAlignmentPairs objects.")
-        .Defunct(msg=wmsg(msg))
-    }
-)
-
