@@ -7,13 +7,11 @@ setMethod("findOverlaps", c("GAlignments", "Vector"),
     function(query, subject, maxgap = 0L, minoverlap = 1L,
              type = c("any", "start", "end", "within"),
              select = c("all", "first", "last", "arbitrary"),
-             algorithm=c("nclist", "intervaltree"),
              ignore.strand = FALSE)
     {
         findOverlaps(grglist(query), subject,
                      maxgap = maxgap, minoverlap = minoverlap,
                      type = match.arg(type), select = match.arg(select),
-                     algorithm = match.arg(algorithm),
                      ignore.strand = ignore.strand)
     }
 )
@@ -22,13 +20,11 @@ setMethod("findOverlaps", c("Vector", "GAlignments"),
     function(query, subject, maxgap = 0L, minoverlap = 1L,
              type = c("any", "start", "end", "within"),
              select = c("all", "first", "last", "arbitrary"),
-             algorithm=c("nclist", "intervaltree"),
              ignore.strand = FALSE)
     {
         findOverlaps(query, grglist(subject),
                      maxgap = maxgap, minoverlap = minoverlap,
                      type = match.arg(type), select = match.arg(select),
-                     algorithm = match.arg(algorithm),
                      ignore.strand = ignore.strand)
     }
 )
@@ -44,13 +40,11 @@ setMethod("findOverlaps", c("GAlignments", "GAlignments"),
     function(query, subject, maxgap = 0L, minoverlap = 1L,
              type = c("any", "start", "end", "within"),
              select = c("all", "first", "last", "arbitrary"),
-             algorithm=c("nclist", "intervaltree"),
              ignore.strand = FALSE)
     {
         findOverlaps(grglist(query), grglist(subject),
                      maxgap = maxgap, minoverlap = minoverlap,
                      type = match.arg(type), select = match.arg(select),
-                     algorithm = match.arg(algorithm),
                      ignore.strand = ignore.strand)
     }
 )
@@ -59,13 +53,11 @@ setMethod("findOverlaps", c("GAlignmentPairs", "Vector"),
     function(query, subject, maxgap = 0L, minoverlap = 1L,
              type = c("any", "start", "end", "within"),
              select = c("all", "first", "last", "arbitrary"),
-             algorithm=c("nclist", "intervaltree"),
              ignore.strand = FALSE)
     {
         findOverlaps(grglist(query), subject,
                      maxgap = maxgap, minoverlap = minoverlap,
                      type = match.arg(type), select = match.arg(select),
-                     algorithm = match.arg(algorithm),
                      ignore.strand = ignore.strand)
     }
 )
@@ -74,13 +66,11 @@ setMethod("findOverlaps", c("Vector", "GAlignmentPairs"),
     function(query, subject, maxgap = 0L, minoverlap = 1L,
              type = c("any", "start", "end", "within"),
              select = c("all", "first", "last", "arbitrary"),
-             algorithm=c("nclist", "intervaltree"),
              ignore.strand = FALSE)
     {
         findOverlaps(query, grglist(subject),
                      maxgap = maxgap, minoverlap = minoverlap,
                      type = match.arg(type), select = match.arg(select),
-                     algorithm = match.arg(algorithm),
                      ignore.strand = ignore.strand)
     }
 )
@@ -89,13 +79,11 @@ setMethod("findOverlaps", c("GAlignmentPairs", "GAlignmentPairs"),
     function(query, subject, maxgap = 0L, minoverlap = 1L,
              type = c("any", "start", "end", "within"),
              select = c("all", "first", "last", "arbitrary"),
-             algorithm=c("nclist", "intervaltree"),
              ignore.strand = FALSE)
     {
         findOverlaps(grglist(query), grglist(subject),
                      maxgap = maxgap, minoverlap = minoverlap,
                      type = match.arg(type), select = match.arg(select),
-                     algorithm = match.arg(algorithm),
                      ignore.strand = ignore.strand)
     }
 )
@@ -104,15 +92,17 @@ setMethod("findOverlaps", c("GAlignmentsList", "Vector"),
     function(query, subject, maxgap = 0L, minoverlap = 1L,
              type = c("any", "start", "end", "within"),
              select = c("all", "first", "last", "arbitrary"),
-             algorithm=c("nclist", "intervaltree"),
              ignore.strand = FALSE)
     {
         hits <- findOverlaps(grglist(unlist(query, use.names = FALSE)),
                              subject, maxgap = maxgap, minoverlap = minoverlap,
                              type = match.arg(type), select = match.arg(select),
-                             algorithm = match.arg(algorithm),
                              ignore.strand = ignore.strand)
-        remapHits(hits, query.map=factor(togroup(query)))
+        ## TODO: Replace 'factor(togroup(PartitioningByWidth(...)))' with
+        ## 'as.factor(PartitioningByWidth(...))' when "as.factor" method for
+        ## ManyToOneGrouping objects becomes available.
+        query_map <- factor(togroup(PartitioningByWidth(query)))
+        remapHits(hits, Lnodes.remapping=query_map)
     }
 )
 
@@ -120,15 +110,17 @@ setMethod("findOverlaps", c("Vector", "GAlignmentsList"),
     function(query, subject, maxgap = 0L, minoverlap = 1L,
              type = c("any", "start", "end", "within"),
              select = c("all", "first", "last", "arbitrary"),
-             algorithm=c("nclist", "intervaltree"),
              ignore.strand = FALSE)
     {
         hits <- findOverlaps(query, grglist(unlist(subject, use.names = FALSE)),
                              maxgap = maxgap, minoverlap = minoverlap,
                              type = match.arg(type), select = match.arg(select),
-                             algorithm = match.arg(algorithm),
                              ignore.strand = ignore.strand)
-        remapHits(hits, subject.map=factor(togroup(subject)))
+        ## TODO: Replace 'factor(togroup(PartitioningByWidth(...)))' with
+        ## 'as.factor(PartitioningByWidth(...))' when "as.factor" method for
+        ## ManyToOneGrouping objects becomes available.
+        subject_map <- factor(togroup(PartitioningByWidth(subject)))
+        remapHits(hits, Rnodes.remapping=subject_map)
     }
 )
 
@@ -136,7 +128,6 @@ setMethod("findOverlaps", c("GAlignmentsList", "GAlignmentsList"),
     function(query, subject, maxgap = 0L, minoverlap = 1L,
              type = c("any", "start", "end", "within"),
              select = c("all", "first", "last", "arbitrary"),
-             algorithm=c("nclist", "intervaltree"),
              ignore.strand = FALSE)
     {
         hits <- findOverlaps(grglist(unlist(query, use.names = FALSE)), 
@@ -144,48 +135,14 @@ setMethod("findOverlaps", c("GAlignmentsList", "GAlignmentsList"),
                              maxgap = maxgap, minoverlap = minoverlap,
                              type = match.arg(type), 
                              select = match.arg(select),
-                             algorithm = match.arg(algorithm),
                              ignore.strand = ignore.strand)
-        remapHits(hits, subject.map=factor(togroup(subject)),
-                  query.map=factor(togroup(query)))
+        ## TODO: Replace 'factor(togroup(PartitioningByWidth(...)))' with
+        ## 'as.factor(PartitioningByWidth(...))' when "as.factor" method for
+        ## ManyToOneGrouping objects becomes available.
+        query_map <- factor(togroup(PartitioningByWidth(query)))
+        subject_map <- factor(togroup(PartitioningByWidth(subject)))
+        remapHits(hits, Lnodes.remapping=query_map,
+                        Rnodes.remapping=subject_map)
     }
 )
 
-
-### =========================================================================
-### findOverlaps-based methods
-### -------------------------------------------------------------------------
-
-.signatures1 <- list(
-    c("GAlignments", "Vector"),
-    c("Vector", "GAlignments"),
-    c("GAlignments", "GAlignments"),
-
-    c("GAlignmentPairs", "Vector"),
-    c("Vector", "GAlignmentPairs"),
-    c("GAlignmentPairs", "GAlignmentPairs"),
-
-    c("GAlignmentsList", "Vector"),
-    c("Vector", "GAlignmentsList"),
-    c("GAlignmentsList", "GAlignmentsList")
-)
-
-.signatures2 <- list(
-    c("GAlignments", "GenomicRanges"),
-    c("GenomicRanges", "GAlignments"),
-    c("GAlignments", "GRangesList"),
-    c("GRangesList", "GAlignments")
-)
-
-setMethods("countOverlaps", c(.signatures1, .signatures2),
-    GenomicRanges:::countOverlaps.definition
-)
-
-setMethods("overlapsAny", .signatures1,
-    GenomicRanges:::overlapsAny.definition
-)
-
-setMethods("subsetByOverlaps", .signatures1,
-    GenomicRanges:::subsetByOverlaps.definition1
-)
-
